@@ -11,7 +11,8 @@
 
 #include "davprotocolbase_p.h"
 
-namespace KDAV {
+namespace KDAV
+{
 /**
  * @short Base class for protocols that implement MULTIGET capabilities
  */
@@ -21,7 +22,7 @@ public:
     /**
      * Destroys the DAV protocol
      */
-    virtual ~DavMultigetProtocol();
+    ~DavMultigetProtocol() override;
 
     /**
      * Returns the XML document that represents a MULTIGET DAV query to
