@@ -138,13 +138,9 @@ XMLQueryBuilder::Ptr CarddavProtocol::collectionsQuery() const
     return XMLQueryBuilder::Ptr(new CarddavCollectionQueryBuilder());
 }
 
-QString CarddavProtocol::collectionsXQuery() const
+bool CarddavProtocol::containsCollection(const QDomElement &propElem) const
 {
-    // clang-format off
-    const QString query(QStringLiteral("//*[local-name()='addressbook' and namespace-uri()='urn:ietf:params:xml:ns:carddav']/ancestor::*[local-name()='response' and namespace-uri()='DAV:']"));
-
-    return query;
-    // clang-format on
+    return !propElem.elementsByTagNameNS(QStringLiteral("urn:ietf:params:xml:ns:carddav"), QStringLiteral("addressbook")).isEmpty();
 }
 
 QVector<XMLQueryBuilder::Ptr> CarddavProtocol::itemsQueries() const
